CreateNetworkOutput class

Constructors

CreateNetworkOutput({String? memberId, String? networkId})
CreateNetworkOutput.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
memberId → String?
The unique identifier for the first member within the network.
final
networkId → String?
The unique identifier for the network.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited