ListInvitationsOutput class

Constructors

ListInvitationsOutput({List<Invitation>? invitations, String? nextToken})
ListInvitationsOutput.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
invitations → List<Invitation>?
The invitations for the network.
final
nextToken → String?
The pagination token that indicates the next set of results to retrieve.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited