ListNetworksOutput class

Constructors

ListNetworksOutput({List<NetworkSummary>? networks, String? nextToken})
ListNetworksOutput.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
networks → List<NetworkSummary>?
An array of NetworkSummary objects that contain configuration properties for each network.
final
nextToken → String?
The pagination token that indicates the next set of results to retrieve.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited