ListNodesOutput class

Constructors

ListNodesOutput({String? nextToken, List<NodeSummary>? nodes})
ListNodesOutput.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextToken → String?
The pagination token that indicates the next set of results to retrieve.
final
nodes → List<NodeSummary>?
An array of NodeSummary objects that contain configuration properties for each node.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited