Member class

Member configuration properties.

Applies only to Hyperledger Fabric.

Constructors

Member({DateTime? creationDate, String? description, MemberFrameworkAttributes? frameworkAttributes, String? id, MemberLogPublishingConfiguration? logPublishingConfiguration, String? name, String? networkId, MemberStatus? status})
Member.fromJson(Map<String, dynamic> json)
factory

Properties

creationDate → DateTime?
The date and time that the member was created.
final
description → String?
An optional description for the member.
final
frameworkAttributes → MemberFrameworkAttributes?
Attributes relevant to a member for the blockchain framework that the Managed Blockchain network uses.
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
The unique identifier of the member.
final
logPublishingConfiguration → MemberLogPublishingConfiguration?
Configuration properties for logging events associated with a member.
final
name → String?
The name of the member.
final
networkId → String?
The unique identifier of the network to which the member belongs.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → MemberStatus?
The status of a member.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited