MemberConfiguration class

Configuration properties of the member.

Applies only to Hyperledger Fabric.

Constructors

MemberConfiguration({required MemberFrameworkConfiguration frameworkConfiguration, required String name, String? description, MemberLogPublishingConfiguration? logPublishingConfiguration})

Properties

description → String?
An optional description of the member.
final
frameworkConfiguration → MemberFrameworkConfiguration
Configuration properties of the blockchain framework relevant to the member.
final
hashCode → int
The hash code for this object.
no setterinherited
logPublishingConfiguration → MemberLogPublishingConfiguration?
Configuration properties for logging events associated with a member of a Managed Blockchain network.
final
name → String
The name of the member.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited