MemberSummary class

A summary of configuration properties for a member.

Applies only to Hyperledger Fabric.

Constructors

MemberSummary({DateTime? creationDate, String? description, String? id, bool? isOwned, String? name, MemberStatus? status})
MemberSummary.fromJson(Map<String, dynamic> json)
factory

Properties

creationDate → DateTime?
The date and time that the member was created.
final
description → String?
An optional description of the member.
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
The unique identifier of the member.
final
isOwned → bool?
An indicator of whether the member is owned by your AWS account or a different AWS account.
final
name → String?
The name of the member.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → MemberStatus?
The status of the member.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited