Network class

Network configuration properties.

Constructors

Network({DateTime? creationDate, String? description, Framework? framework, NetworkFrameworkAttributes? frameworkAttributes, String? frameworkVersion, String? id, String? name, NetworkStatus? status, VotingPolicy? votingPolicy, String? vpcEndpointServiceName})
Network.fromJson(Map<String, dynamic> json)
factory

Properties

creationDate → DateTime?
The date and time that the network was created.
final
description → String?
Attributes of the blockchain framework for the network.
final
framework → Framework?
The blockchain framework that the network uses.
final
frameworkAttributes → NetworkFrameworkAttributes?
Attributes of the blockchain framework that the network uses.
final
frameworkVersion → String?
The version of the blockchain framework that the network uses.
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
The unique identifier of the network.
final
name → String?
The name of the network.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → NetworkStatus?
The current status of the network.
final
votingPolicy → VotingPolicy?
The voting rules for the network to decide if a proposal is accepted.
final
vpcEndpointServiceName → String?
The VPC endpoint service name of the VPC endpoint service of the network. Members use the VPC endpoint service name to create a VPC endpoint to access network resources.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited