NetworkFabricAttributes class

Attributes of Hyperledger Fabric for a network.

Constructors

NetworkFabricAttributes({Edition? edition, String? orderingServiceEndpoint})
NetworkFabricAttributes.fromJson(Map<String, dynamic> json)
factory

Properties

edition → Edition?
The edition of Amazon Managed Blockchain that Hyperledger Fabric uses. For more information, see Amazon Managed Blockchain Pricing.
final
hashCode → int
The hash code for this object.
no setterinherited
orderingServiceEndpoint → String?
The endpoint of the ordering service for the network.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited