NetworkFrameworkAttributes class

Attributes relevant to the network for the blockchain framework that the network uses.

Properties

ethereum → NetworkEthereumAttributes?
Attributes of an Ethereum network for Managed Blockchain resources participating in an Ethereum network.
final
fabric → NetworkFabricAttributes?
Attributes of Hyperledger Fabric for a Managed Blockchain network that uses Hyperledger Fabric.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited