Node class

Configuration properties of a node.

Constructors

Node({String? availabilityZone, DateTime? creationDate, NodeFrameworkAttributes? frameworkAttributes, String? id, String? instanceType, NodeLogPublishingConfiguration? logPublishingConfiguration, String? memberId, String? networkId, StateDBType? stateDB, NodeStatus? status})
Node.fromJson(Map<String, dynamic> json)
factory

Properties

availabilityZone → String?
The Availability Zone in which the node exists.
final
creationDate → DateTime?
The date and time that the node was created.
final
frameworkAttributes → NodeFrameworkAttributes?
Attributes of the blockchain framework being used.
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
The unique identifier of the node.
final
instanceType → String?
The instance type of the node.
final
logPublishingConfiguration → NodeLogPublishingConfiguration?
Configuration properties for logging events associated with a peer node on a Hyperledger Fabric network on Managed Blockchain.
final
memberId → String?
The unique identifier of the member to which the node belongs.
final
networkId → String?
The unique identifier of the network that the node is on.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stateDB → StateDBType?
The state database that the node uses. Values are LevelDB or CouchDB.
final
status → NodeStatus?
The status of the node.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited