Proposal class

Properties of a proposal on a Managed Blockchain network.

Applies only to Hyperledger Fabric.

Constructors

Proposal({ProposalActions? actions, DateTime? creationDate, String? description, DateTime? expirationDate, String? networkId, int? noVoteCount, int? outstandingVoteCount, String? proposalId, String? proposedByMemberId, String? proposedByMemberName, ProposalStatus? status, int? yesVoteCount})
Proposal.fromJson(Map<String, dynamic> json)
factory

Properties

actions → ProposalActions?
The actions to perform on the network if the proposal is APPROVED.
final
creationDate → DateTime?
The date and time that the proposal was created.
final
description → String?
The description of the proposal.
final
expirationDate → DateTime?
The date and time that the proposal expires. This is the CreationDate plus the ProposalDurationInHours that is specified in the ProposalThresholdPolicy. After this date and time, if members have not cast enough votes to determine the outcome according to the voting policy, the proposal is EXPIRED and Actions are not carried out.
final
hashCode → int
The hash code for this object.
no setterinherited
networkId → String?
The unique identifier of the network for which the proposal is made.
final
noVoteCount → int?
The current total of NO votes cast on the proposal by members.
final
outstandingVoteCount → int?
The number of votes remaining to be cast on the proposal by members. In other words, the number of members minus the sum of YES votes and NO votes.
final
proposalId → String?
The unique identifier of the proposal.
final
proposedByMemberId → String?
The unique identifier of the member that created the proposal.
final
proposedByMemberName → String?
The name of the member that created the proposal.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → ProposalStatus?
The status of the proposal. Values are as follows:
final
yesVoteCount → int?
The current total of YES votes cast on the proposal by members.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited